InfluxDB — Glances 3.1.3 documentation

# InfluxDB

You can export statistics to an `InfluxDB` server (time series server). The connection should be defined in the Glances configuration file as following:

    [influxdb]
    host=localhost
    port=8086
    protocol=http
    user=root
    password=root
    db=glances
    tags=foo:bar,spam:eggs

and run Glances with:

    $ glances --export influxdb

Glances generates a lot of columns, e.g., if you have many running Docker containers, so you should use the `tsm1` engine in the InfluxDB configuration file (no limit on columns number).

Note: if you want to use SSL, please set ‘protocol=https’.

## Grafana

For Grafana users, Glances provides a dedicated dashboard.

To use it, just import the file in your `Grafana` web interface.